@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
+from contenttypes.basic import _
 from contenttypes.basic.fields.osmap import OSMapField
-from plone.app.dexterity import _
 from plone.autoform.interfaces import IFormFieldProvider
 from plone.dexterity.interfaces import IDexterityContent
 from plone.supermodel import model
